import Vue from 'vue'
import VueRouter from 'vue-router'

import Home from '../views/Index.vue'

import { SYSTEM_NAME } from '@/utils/constant'

import { platform, settingNavigationTitle } from '@/utils/dingtalk';

Vue.use(VueRouter)

const routes = [
  // {
  //   path: '/',
  //   redirect: 'ExamineDetail',
  // },

  {
    path: '/',
    name: 'Home',
    meta: {
      title: '办公系统',
      showTabBar: true
    },
    component: Home
  },
  

  // ====== 申请页面
  {
    path: '/applyfor',
    name: 'Applyfor',
    meta: {
      keepAlive: true
    },
    component: () => import(/* webpackChunkName: "index" */ '../views/applyfor/index.vue')
  },

  {
    path: '/applyfor/peers-out-form',
    name: 'PeersOutForm',
    meta:{
      title: '外部同行人', 
    },
    component: () => import(/* webpackChunkName: "index" */ '../views/applyfor/peersOutForm.vue')
  },
  {
    path: '/applyfor/type6-before',
    name: 'AskForLeave',
    component: () => import(/* webpackChunkName: "type6" */ '../views/applyfor/askForLeaveType.vue')
  },
  {
    path: '/applyfor/product-store',
    name: 'ProductStore',
    meta: {
      title: '商品库'
    },
    component: () => import(/* webpackChunkName: "applyfor" */ '../views/applyfor/ProductStore.vue')
  },

  {
    path: '/applyfor/goods',
    name: 'Goods',
    meta: {
      title: '新增/修改商品'
    },
    component: () => import(/* webpackChunkName: "applyfor" */ '../views/applyfor/goods.vue')
  },
  {
    path: '/applyfor/goods-specifications',
    name: 'GoodsSpeci',
    meta: {
      title: '商品规格'
    },
    component: () => import(/* webpackChunkName: "applyfor" */ '../views/applyfor/goods-specifications.vue')
  },

  {
    path: '/applyfor/approval-form',
    name: 'CApprovalForm',
    meta: {
      title: '采购审批单'
    },
    component: () => import(/* webpackChunkName: "applyfor" */ '../views/applyfor/approval-form.vue')
  },

  {
    path: '/applyfor/approval-form-sel',
    name: 'CApprovalFormSel',
    meta: {
      title: '采购物品明细'
    },
    component: () => import(/* webpackChunkName: "applyfor" */ '../views/applyfor/approval-form-sel.vue')
  },

  // NOTE：我的审核状态
  {
    path: '/apply-state',
    name: 'ApplyState',
    meta: {
      title: '我的审核状态'
    },
    component: () => import(/* webpackChunkName: "index" */ '../views/apply-state/index.vue')
  },


  // ====== 审核页面
  {
    path: '/approve',
    name: 'Approve',
    meta: {
      showTabBar: true,
      title: '我的审批'
      
    },
    // route level code-splitting
    // this generates a separate chunk (about.[hash].js) for this route
    // which is lazy-loaded when the route is visited.
    component: () => import(/* webpackChunkName: "approve" */ '../views/Approve.vue')
  },
  {
    path: '/approve/search',
    name: 'Search',
    meta: {
      title: '搜索申请审批'
    },
    component: () => import(/* webpackChunkName: "approve" */ '../views/approve/search.vue')
  },
  {
    path: '/approve/examine',
    name: 'Examine',
    meta: {
      title: '审核'
    },
    component: () => import(/* webpackChunkName: "approve" */ '../views/approve/examine.vue')
  },
  {
    path: '/approve/detail',
    name: 'ExamineDetail',
    meta: {
      title: '审批单详情'
    },
    component: () => import(/* webpackChunkName: "approve" */ '../views/approve/detail.vue')
  },

  {
    meta: {
      title: '上传返回结果',
    },
    path: '/approve/feedback',
    name: 'FeedbackResult',
    component: () => import(/* webpackChunkName: "approve" */ '../views/approve/feedback-results.vue')
  },

  {
    meta: {
      title: '采购明细'
    },
    path: '/approve/procure-info',
    name: 'ProcureInfo',
    component: () => import(/* webpackChunkName: "approve" */ '../views/approve/procure-info.vue')
  },


  // ====== 我的页面
  {
    path: '/my',
    name: 'My',
    meta: { title: '我的', showTabBar: true },
    component: () => import(/* webpackChunkName: "personnel" */ '../views/My.vue'),
  },
  {
    path: '/user-info',
    name: 'Userinfo',
    meta: {
      title: '我的信息'
    },
    component: () => import(/* webpackChunkName: "personnel" */ '../views/personal/Userinfo.vue')
  },
  {
    path: '/user-info/single-info',
    name: 'Singleinfo',
    meta: {
      title: '个人信息页面'
    },
    component: () => import(/* webpackChunkName: "personnel" */ '../views/personal/single-info.vue')
  },
  {
    path: '/update/nickname',
    name: 'Nickname',
    meta: {
      title: '我的昵称'
    },
    component: () => import(/* webpackChunkName: "personnel" */ '../views/personal/nickname.vue')
  },

  {
    path: '/update/mobile',
    name: 'Mobile',
    meta: {
      title: '我的手机号'
    },
    component: () => import(/* webpackChunkName: "personnel" */ '../views/personal/phone-number.vue')
  },
  {
    path: '/update/signature',
    name: 'Signature',
    meta: {
      title: '我的签名'
    },
    component: () => import(/* webpackChunkName: "personnel" */ '../views/personal/signature.vue')
  },

  // --- review files ---
  {
    path: '/review/pdf',
    name: 'ReviewPdf',
    meta: {
      title: '预览'
    },
    component: () => import(/* webpackChunkName: "review" */ '../views/review/Pdf.vue')
  },
  {
    path: '/review/doc',
    name: 'ReviewDoc',
    meta: {
      title: '预览'
    },
    component: () => import(/* webpackChunkName: "review" */ '../views/review/Doc.vue')
  },
  {
    path: '/review/excel',
    name: 'ReviewExcel',
    meta: {
      title: '预览'
    },
    component: () => import(/* webpackChunkName: "review" */ '../views/review/Excel.vue')
  }
  
]

const router = new VueRouter({
  routes,
  mode: 'hash'
})

router.beforeEach((to, from, next) => {
  // console.log('>>>>> beforeEach >>>>>');
  // console.log('to', to);
  // console.log('form', from);
  // console.log('<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<');

  if (to.meta.title) {
    document.title = to.meta.title || SYSTEM_NAME
  }

  try {
    if (platform !== 'notInDingTalk') {
      settingNavigationTitle({
        title: document.title
      })
    }
  } catch (e) {} /* eslint-disable-line */

  next()
})

export default router
