import { getRequestAuthCode } from '@/utils/dingtalk'
import { login } from '@/api/login'
import { getUserinfo } from '@/api/member'
// import { Toast } from 'vant'

// 签名状态:1=未操作,2=待审核,3=审核通过,4=审核驳回
const signatureStateEnum = [undefined, '未操作', '待审核', '已通过', '已驳回']

const state = {
    name: '',
    schoolName: '',
    subjectLogo: '',
    mobile: '',
    userinfo: {},
    signatureStateText: '', // 个签
    token: ''
}

const getters = {
    getTags(state){
        if (!state.userinfo.title) return []
        let title = state.userinfo.title
        // NOTE: 数据库中是中文“、”
        return title.split('、')
    },
    
    getDepartments (state) {
        let userinfo = state.userinfo
        if (!userinfo.department_list) return ''
        return userinfo.department_list.map(item => item.name).join('、')
    },

    // NOTE: 获取组织成员信息
    teamMemberInfomation (state, getters) {
        let values = [
            state.schoolName,
            state.name,
            getters.getTags.join('、')
        ]
        let labels = [
            '企业/组员',
            '姓名',
            '职务'
        ]
        return labels.map((label, index) => ({
            label,
            val: values[index]
        }))
    }
}

const mutations = {
    UPDATE_USER_DATA: (state, payload) => {
        const { mobile, name, subject, subject_image } = payload.data
        state.userinfo = payload.data
        state.mobile = mobile
        state.name = name
        state.schoolName = subject
        state.subjectLogo = subject_image
        state.signatureStateText = signatureStateEnum[payload.data.signature_status] || ''
    },
    // 更新用户Token
    // UPDATE_USER_TOKEN: (state, payload) => (state.token = payload.token),
    UPDATE_USER_TOKEN: (state, payload) => {
        state.token = payload.token
    },
}

const actions = {
    async getUserInfo ({ commit }) {
        try {
            const result = await getUserinfo()
            if (result.code === 1) {
                const data = result.data
                commit({
                    type: 'UPDATE_USER_DATA',
                    data
                })
            }
        } catch (error) {
            console.log('%c getUserInfoError >>>', 'background: blue; color: #fff', error);
        }
    },

    // 登录获取token
    async login ({ dispatch, commit }) {
        try { 
            const code = await getRequestAuthCode()
            const result = await login(code)
            console.log('%c GetLogin >>>', 'background: blue; color: #fff', code, result);
            if (result.code === 1) {
                commit({
                    type: 'UPDATE_USER_TOKEN',
                    token: result.data
                })
                dispatch('getUserInfo')
            }
        } catch (error) {
            console.log('%c login error >>>', 'background: blue; color: #fff', error);
        }
    },
}

export default {
    namespaced: true,
    state,
    getters,
    mutations,
    actions
}