/**
 * @description 设置审核Row的数据内容等
 * 
  // datalist: [
  //     {
  //         title: '审批编号',
  //         value: '20222110741458005442684',
  //     },
  //     {
  //         title: '合同编号',
  //         value: '20222110741458005442684',
  //         type: 'link' // 代表它是一个链接
  //     },
  //     {
  //         title: '申请日期',
  //         value: '2022-11-07',
  //         type: 'date' // 代表返回的是unixtime 时间戳需要自己转义`dayjs`
  //     },
  //     {
  //         type: 'projects',
  //         title: '申购明细',
  //         value: [
  //             {
  //                 projectName: '学生冬季校服',
  //                 count: 20,
  //                 tags: ['蓝色', '165cm'],
  //                 money: 56025
  //             }
  //         ]
  //     },
  //     {
  //         type: 'files', // 代表当前是 上传的文件
  //         title: '附件材料',
  //         value: [
  //             {
  //                 type: 'pdf',
  //                 name: '采购说明.pdf',
  //                 size: '264.45KB'
  //             }
  //         ]
  //     },
  //     {
  //         type: 'images', // 代表当前是图片组
  //         title: '图片',
  //         value: [
  //             {
  //                 url: 'http://xxxxx'
  //             }
  //         ]
  //     }
  // ]
 */

import store from "@/store"
const degree2Txt = store.getters['enum/getDegreeText']
const maintainTypeList = store.getters['enum/getMaintainText']

const getPayTypeText = store.getters["enum/getPayTypeText"]
const getapplyTypeText = store.getters["enum/getapplyTypeText"]
const getOfferTypeList = store.getters["enum/getOfferTypeList"]
const getEvectionTypeList = store.getters["enum/getEvectionTypeList"]
const getLeaveTypeTypeList = store.getters["enum/getLeaveTypeTypeList"]
const getContractTypeList = store.getters["enum/getContractTypeList"]

import { getByteShowSize } from '@/utils/util'

// 修改明细中arrsJSON
const formatList = arrs => (arrs.map(item => ({...item, goods_stock: JSON.parse(item.goods_stock)})))

// 申购审批详情
function getModule1(data){ /* eslint-disable-line */
  const { order_no, department_data, apply_date, module_info, apply_user, apply_goods, contract } = data
  
  return [
    {
      title: '审批编号',
      value: order_no
    },

    Array.isArray(contract) && contract.length ? {
      type: 'contract-number',
      details: data, // 可以跳转module_9的detail.
      title: '合同编号',
      value: contract
    } : undefined,
    
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: apply_date
    },
    {
      title: '申请人',
      value: apply_user.name
    },
    {
      title: '申请事由',
      value: module_info.reason
    },
    {
      title: '申购类型',
      value: getapplyTypeText(module_info.type)
    },
    Array.isArray(apply_goods) && apply_goods.length ? {
      module: 1,
      type: 'projects',
      title: '申购明细',
      value: formatList(apply_goods)
    } : undefined,
    {
      title: '总金额',
      value: module_info.total_amount || '-'
    },
    {
      title: '预计申购完成日期',
      value: module_info.start_time	
    },
    module_info.document_text.length ? {
      type: 'files',
      title: '附件材料',
      value: module_info.document_text.map(doc => ({
        url: doc.fullurl,
        name: doc.name,
        size: getByteShowSize(doc.size)
      }))
    } : undefined,
    module_info.images_text.length ? {
      type: 'images',
      title: '图片',
      value: module_info.images_text.map(img => ({
        url: img
      }))
    } : undefined,
    {
      title: '支付方式',
      value: getPayTypeText(module_info.pay_type)
    }
  ]
}

// 呈批申请
function getModule2(data){ /* eslint-disable-line */
  const { order_no, department_data, apply_date, module_info, apply_user } = data
  return [
    {
      title: '审批编号',
      value: order_no
    },
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: apply_date
    },
    {
      title: '申请人',
      value: apply_user.name
    },
    {
      title: '呈批类型',
      value: getOfferTypeList(data.type)
    },
    {
      title: '发文字号',
      value: `${module_info.word_size}`
    },
    {
      title: '缓急程度',
      value: degree2Txt(module_info.desc)
    },
    {
      title: '印制份数',
      value: `${module_info.number}`
    },
    {
      title: '申请标题',
      value: module_info.reason
    },
    {
      title: '申请内容',
      value: module_info.remark
    },
    module_info.document_text.length ? {
      type: 'files',
      title: '附件材料',
      value: module_info.document_text.map(doc => ({
        url: doc.fullurl,
        name: doc.name,
        size: getByteShowSize(doc.size)
      }))
    } : undefined
  ]
}

// 入库申请
function getModule3(data) { /* eslint-disable-line */
  const { order_no, department_data, module_info, apply_user, stock_goods } = data
  return [
    {
      title: '审批编号',
      value: order_no
    },
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: data.apply_date
    },
    {
      title: '申请人',
      value: apply_user.name
    },
    Array.isArray(stock_goods) ? {
      type: 'projects',
      title: '物品明细',
      value: formatList(stock_goods)
    } : undefined,
    module_info.document_text.length ? {
      type: 'files',
      title: '附件材料',
      value: module_info.document_text.map(doc => ({
        url: doc.fullurl,
        name: doc.name,
        size: getByteShowSize(doc.size)
      }))
    } : undefined,
    module_info.images_text.length ? {
      type: 'images',
      title: '图片',
      value: module_info.images_text.map(img => ({
        url: img
      }))
    } : undefined,
    {
      title: '其他补充说明',
      value: module_info.remark
    }
  ]
}

// 领用申请
function getModule4(data) { /* eslint-disable-line */
  const { order_no, department_data, module_info, apply_user, use_goods } = data
  return [
    {
      title: '审批编号',
      value: order_no
    },
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: data.apply_date
    },
    {
      title: '申请人',
      value: apply_user.name
    },
    Array.isArray(use_goods) ? {
      id: data.id,
      module: 4,
      type: 'projects',
      title: '物品明细',
      value: formatList(use_goods)
    } : undefined,
    module_info.document_text.length ? {
      type: 'files',
      title: '附件材料',
      value: module_info.document_text.map(doc => ({
        url: doc.fullurl,
        name: doc.name,
        size: getByteShowSize(doc.size)
      }))
    } : undefined,
    module_info.remark ? {
      title: '其他补充说明',
      value: module_info.remark
    } : undefined
  ]
}

// 出差申请
function getModule5(data) { /* eslint-disable-line */
  const { order_no, department_data, module_info, apply_user } = data
  return [
    {
      title: '审批编号',
      value: order_no
    },
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: data.apply_date
    },
    {
      title: '申请人',
      value: apply_user.name
    },
    {
      title: '出差事由',
      value: module_info.reason
    },
    {
      title: '同行人员',
      value: Array.isArray(data.peer_user) && data.peer_user.length ? data.peer_user.map(user => (user.name)).join('、') : '暂无同行人员'
    },
    {
      title: '出差开始时间',
      value: module_info.start_time
    },
    {
      title: '出差结束时间',
      value: module_info.end_time
    },
    module_info.document_text.length ? {
      type: 'files',
      title: '附件材料',
      value: module_info.document_text.map(doc => ({
        url: doc.fullurl,
        name: doc.name,
        size: getByteShowSize(doc.size)
      }))
    } : undefined,
    module_info.images_text.length ? {
      type: 'images',
      title: '图片',
      value: module_info.images_text.map(img => ({
        url: img
      }))
    } : undefined,
    {
      title: '出差类型',
      value: getEvectionTypeList(module_info.type)
    },
    // NOTE: type === 1 show that.
    module_info.type == 1 ? {
      title: '是否跨关内关外',
      value: module_info.is_who == 0 ? '否' : '是'
    } : undefined,
    module_info.remark ? {
      title: '预算金额',
      value: module_info.remark
    } : undefined
  ]
}

// 请假申请
function getModule6(data) { /* eslint-disable-line */
  const { order_no, department_data, module_info, apply_user } = data
  return [
    {
      title: '审批编号',
      value: order_no
    },
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: data.apply_date
    },
    {
      title: '申请人',
      value: apply_user.name
    },
    {
      title: '请假类型',
      value: getLeaveTypeTypeList(module_info.type)
    },
    {
      title: '请假开始时间',
      value: `${module_info.start_time} ${module_info.start_am}`
    },
    {
      title: '请假结束时间',
      value: `${module_info.end_time} ${module_info.end_am}`
    },
    {
      title: '请假时长(H)',
      value: module_info.time
    },
    {
      title: '原因',
      value: module_info.reason
    },
    module_info.document_text.length ? {
      type: 'files',
      title: '附件材料',
      value: module_info.document_text.map(doc => ({
        url: doc.fullurl,
        name: doc.name,
        size: getByteShowSize(doc.size)
      }))
    } : undefined,
    module_info.images_text.length ? {
      type: 'images',
      title: '图片',
      value: module_info.images_text.map(img => ({
        url: img
      }))
    } : undefined,
    {
      title: '是否离“深”',
      value: module_info.remark
    }
  ]
}

// 用车申请
function getModule7(data) { /* eslint-disable-line */
  const { order_no, department_data, module_info, apply_user } = data
  return [
    {
      title: '审批编号',
      value: order_no
    },
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: data.apply_date
    },
    {
      title: '申请人',
      value: apply_user.name
    },
    {
      title: '出发地点',
      value: module_info.reason
    },
    {
      title: '出发时间',
      value: module_info.start_time
    },
    {
      title: '到达地点',
      value: module_info.reach_address
    },
    {
      title: '返回时间',
      value: module_info.end_time
    },
    {
      title: '返回地点',
      value: module_info.end_address
    },
    module_info.document_text.length ? {
      type: 'files',
      title: '附件材料',
      value: module_info.document_text.map(doc => ({
        url: doc.fullurl,
        name: doc.name,
        size: getByteShowSize(doc.size)
      }))
    } : undefined,
    module_info.images_text.length ? {
      type: 'images',
      title: '图片',
      value: module_info.images_text.map(img => ({
        url: img
      }))
    } : undefined,
  ]
}

// 维修申请
function getModule8(data) { /* eslint-disable-line */
  const { order_no, department_data, module_info} = data
  return [
    {
      title: '审批编号',
      value: order_no
    },
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: data.apply_date
    },
    {
      title: '维修分类',
      value: maintainTypeList(module_info.type),
    },
    {
      title: '维修地点',
      value: module_info.reason,
    },

    {
      title: '维修内容',
      value: module_info.desc,
    },
    module_info.images_text.length ? {
      type: 'images',
      title: '图片',
      value: module_info.images_text.map(img => ({
        url: img
      }))
    } : undefined,
  ]
}

// 合同呈批
function getModule9(data) { /* eslint-disable-line */
  const { order_no, department_data, module_info, apply_user } = data
  return [
    {
      title: '审批编号',
      value: order_no
    },
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: data.apply_date
    },
    {
      title: '申请人',
      value: apply_user.name
    },
    {
      title: '合同类型',
      value: getContractTypeList(module_info.type)
    },
    data.reason ? {
      title: '合同编号',
      value: `${data.reason}`
    } : undefined,
    {
      title: '缓急程度',
      value: degree2Txt(module_info.desc)
    },
    {
      title: '印制份数',
      value: `${module_info.number}`
    },
    {
      title: '发放范围',
      value: `${module_info.scope}`
    },
    {
      title: '法务意见',
      value: `${module_info.legal_opinion}`
    },
    module_info.document_text.length ? {
      type: 'files',
      title: '附件材料',
      value: module_info.document_text.map(doc => ({
        url: doc.fullurl,
        name: doc.name,
        size: getByteShowSize(doc.size)
      }))
    } : undefined,
    {
      title: '备注',
      value: module_info.remark
    }
  ]
}

// 收文批阅
function getModule10(data) { /* eslint-disable-line */
  const { order_no, department_data, apply_date, module_info, apply_user } = data
  return [
    {
      title: '审批编号',
      value: order_no
    },
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: apply_date
    },
    {
      title: '发起人',
      value: apply_user.name
    },
    {
      title: '创建人',
      value: module_info.founder
    },
    {
      title: '来文单位名称',
      value: module_info.desc
    },
    {
      title: '收文序号',
      value: module_info.serial_number
    },
    {
      title: '文件名称',
      value: module_info.reason
    },
    {
      title: '收文日期',
      value: module_info.start_time	
    },
    {
      title: '内容摘要',
      value: module_info.remark
    },
    {
      title: '缓急程度',
      value: degree2Txt(module_info.degree)
    },
    module_info.document_text.length ? {
      type: 'files',
      title: '附件材料',
      value: module_info.document_text.map(doc => ({
        url: doc.fullurl,
        name: doc.name,
        size: getByteShowSize(doc.size)
      }))
    } : undefined,
  ]
}

// 学校文件  
function getModule11(data) { /* eslint-disable-line */
  const { order_no, department_data, module_info, apply_user } = data
  return [
    {
      title: '审批编号',
      value: order_no
    },
    {
      title: '所在部门',
      value: department_data.map(department => (department.name)).join(',')
    },
    {
      title: '申请日期',
      value: data.apply_date
    },
    {
      title: '申请人',
      value: apply_user.name
    },
    {
      title: '拟稿部门',
      value: module_info.department
    },
    {
      title: '文件名称',
      value: module_info.reason
    },
    {
      title: '落款',
      value: module_info.department_sign
    },
    {
      title: '上会情况',
      value: module_info.remark
    },
    module_info.document_text.length ? {
      type: 'files',
      title: '附件材料',
      value: module_info.document_text.map(doc => ({
        url: doc.fullurl,
        name: doc.name,
        size: getByteShowSize(doc.size)
      }))
    } : undefined,
    {
      title: '缓急程度',
      value: degree2Txt(module_info.desc)
    },
    {
      title: '拟发文时间',
      value: module_info.start_time	
    },
    {
      title: '文件号',
      value: module_info.serial_number
    },
  ]
}

export const formatApplyforRows = (data) => {
  let type = data.module

  if (typeof type !== 'number') type = Number(type)

  let arrs = []

  if (![1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11].includes(type)) return [];
  const moduleFunc = `getModule${type}`
  arrs =  eval(`${moduleFunc}(data)`)

  // NOTE: 过滤为undefined字段
  return arrs.filter(item => (item))
}
