import axios from 'axios'

import { Toast } from 'vant'
// import { MessageBox, Message } from 'element-ui'

import store from '@/store/index'
// import { getToken } from '@/utils/auth'

// create an axios instance
const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API + '/api/', // url = base url + request url
  // withCredentials: true, // send cookies when cross-domain requests
  timeout: 5000 // request timeout
})

// request interceptor
service.interceptors.request.use(
  config => {
    // console.log('%c config >>>', 'background: blue; color: #fff', config);
    // NOTE: 上传接口 `content-type`有变化
    if (config.url === 'upload/upload') {
      config.headers['Content-Type'] = "multipart/form-data"
      config.timeout = 50000 // 上传文件给50s
    } else if (config.url === 'approveinfo/download') {
      config.timeout = 50000 // 50s下载时间
    }

    if (store.getters.token) {
      // let each request carry token
      // ['X-Token'] is a custom headers key
      // please modify it according to the actual situation
      config.headers['Authorization'] = store.getters.token
      // config.headers['X-Token'] = getToken()
    }
    return config
  },
  error => {
    // do something with request error
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
  */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  response => {
    const res = response.data

    // if the custom code is not 20000, it is judged as an error.
    if (res.code !== 1) {
      console.log(res);
      Toast(res.msg || '网络错误,请联系管理员')
      return Promise.reject(new Error(res.msg || '网络错误,请联系管理员'))
    } else {
      return res
    }
  },
  error => {
    console.log('err' + error) // for debug
    // Message({
    //   message: error.message,
    //   type: 'error',
    //   duration: 5 * 1000
    // })
    return Promise.reject(error)
  }
)

export default service